
**********Software version: Stata/MP 13.1


clear all
clear
capture log close
set more off


* Change Directory to "\DataFiles"
cd "C:\Dropbox\CivilExam\FinalFiles\DataFiles"
use Data\NewComers.dta, clear






************************************************************************************************************************************
**********************************        Variables definition

************************************************************************************************************************************



** Dummy indicator
gen jinshi_d=(jinshi>0)
gen official_d=(official>0)
gen newcomer_d=(new_comer>0)

** Polynomials of ln popu.
sum lnpop
gen lnpop2=(lnpop-13.61967)^2
gen lnpop3=(lnpop-13.61967)^3



************** Beta coefficient: normailized by standard deviation
*** Time invariant variables:
foreach x of varlist  jinshi official jinshi_d official_d lnquota lnpop lnpop2 lnpop3{
sum `x' if year==1904
gen `x'_beta=`x'/r(sd)
}


*** Time variant variables:
foreach x of varlist newcomer_d new_comer {
sum `x' if year==1904
gen `x'_beta=`x'/r(sd) if year==1904
sum `x' if year==1907
replace `x'_beta=`x'/r(sd) if year==1907
}









************************************************************************************************************************************
**********************************         Regressions

************************************************************************************************************************************


************************* Table 6A: The Role of Prospect I: Quotas and Political Newcomers Under Different Regimes

reg jinshi_d_beta lnquota_beta lnpop_beta lnpop2_beta lnpop3_beta i.provcd if year==1904
outreg2  lnquota_beta using Tables\Table_6a.doc, p bracket bdec(3) rdec(3) nocons replace

reg jinshi_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta i.provcd if year==1904
outreg2  lnquota_beta  using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append

reg official_d_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta i.provcd if year==1904
outreg2  lnquota_beta  using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append

reg official_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta  i.provcd if year==1904
outreg2  lnquota_beta using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append

reg newcomer_d_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta  i.provcd if year==1904
outreg2  lnquota_beta   using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append
est store a1

reg new_comer_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta i.provcd if year==1904
outreg2  lnquota_beta  using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append
est store a2

***********************

reg newcomer_d_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta  i.provcd if year==1907
outreg2  lnquota_beta  using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append
est store b1

reg new_comer_beta lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta i.provcd if year==1907
outreg2  lnquota_beta   using Tables\Table_6a.doc, p bracket  bdec(3) rdec(3) nocons  append
est store b2


****** Examining the change in the coefficients
hausman a1 b1
hausman b2 a2



** Hausman test
hausman a1 b1
hausman b2 a2


************** Examing the chagne in the coefficients: Fixed-effects:

*** Post-abolition dummy
gen post04=(year>1904)

foreach x of varlist lnquota_beta lnpop_beta  lnpop2_beta lnpop3_beta {
gen post04_`x'=post04*`x'
}

sort prefid post04
tsset prefid post04
xi: xtreg newcomer_d_beta lnquota_beta lnpop_beta post04_lnquota_beta post04_lnpop_beta  post04_lnpop2_beta   post04_lnpop3_beta  post04, fe r
xi: xtreg new_comer_beta lnquota_beta lnpop_beta post04_lnquota_beta post04_lnpop_beta post04_lnpop2_beta   post04_lnpop3_beta post04, fe r









