**********Software version: Stata/MP 13.1


clear all
clear
capture log close
set more off



* Change Directory to "\DataFiles"
cd "C:\Dropbox\CivilExam\FinalFiles\DataFiles"
use  Data\PrefYear.dta, clear



************************************************************************************************************************************
**********************************        Variables definition

************************************************************************************************************************************




* Dummy: 1(Revolutionary>0)
gen member_d=(member>0)
* Revolutioinary per million population
gen membersh=member*1000000/pop

gen lnquota=ln(quota)

gen lnquota0=ln(quota0)

gen delquota=lnquota-lnquota0

* log
gen lnpop=ln(pop)

* Polynomials of population
sum lnpop
gen lnpop2=(lnpop-13.61967)^2
gen lnpop3=(lnpop-13.61967)^3


gen quotash=1000000*quota/pop

gen lnsize=ln(size)

gen newspc=1000*newspaper/pop




gen post04=(year>1904)

********************** Gen interactioin with Post-abolition dummy
gen lnquota_post04=lnquota*post04

local controls "lnpop lnpop2 lnpop3 lnsize coast mainriver treaty small middle large rivernum2riv lnriverl  change_p1p0 lnpscholar0 taxpc1820 pcapital ranka_p rankb_p rankc_p rankd_p rice foxmillet spotato mean_mdf_ds river70num2riv othriver70num2riv river80num2riv othriver80num2riv river90num2riv othriver90num2riv river100num2riv othriver100num2riv river110num2riv othriver110num2riv river120num2riv othriver120num2riv " 
foreach var of varlist `controls' { 
gen post04_`var'=`var'*post04
}

********************** Gen interaction with year dummies

tabu year, gen (ydummy)
sum ydummy*

forvalues i=2(1)7 { 
gen lnquota_year`i'=ydummy`i'*lnquota
}

forvalues i=2(1)7 { 
gen lnpop_year`i'=ydummy`i'*lnpop
gen lnpop2_year`i'=ydummy`i'*lnpop2
gen lnpop3_year`i'=ydummy`i'*lnpop3
gen coast_year`i'=ydummy`i'*coast
gen mainriver_year`i'=ydummy`i'*mainriver
gen lnsize_year`i'=ydummy`i'*lnsize
gen treaty_year`i'=ydummy`i'*treaty
gen small_year`i'=ydummy`i'*small
gen middle_year`i'=ydummy`i'*middle
gen large_year`i'=ydummy`i'*large
}





********************** Government officials
* pre-abolition
gen lnoff=ln(official+1)
* in the year of 1905
gen lnoff1905=ln(off1905+1)

* triple effect with lnquota lnpop
sum lnquota lnpop
foreach x of varlist lnoff lnoff1905{
gen `x'_post04=`x'*post04
sum `x'
gen `x'quota_post04=(`x'-r(mean))*(lnquota-4.440656)*post04
sum `x'
gen `x'pop_post04=(`x'-r(mean))*(lnpop-13.61967)*post04
}


******************** Fragmentation


****

sum fragm
gen post04_fragm=post04*(fragm-r(mean))
gen post04_fragm_lnq=post04*(fragm-r(mean))*(lnquota-4.440656)
gen post04_fragm_lnpop=post04*(fragm-r(mean))*(lnpop-13.61967 )

sum rqindex
gen post04_rqindex=post04*(rqindex-r(mean))
gen post04_rqindex_lnq=post04*(rqindex-r(mean))*(lnquota-4.440656)
gen post04_rqindex_lnpop=post04*(rqindex-r(mean))*(lnpop-13.61967 )


******************** Higher levels of candidates
* the ration of quota to pop
gen quota2pop=100*quota*170/pop
gen post04_quota2popu=post04*quota2pop

* the ratio of jinshi to quota
gen jinshi2quota=100*jinshi/(quota*170)
gen post04_jinshi2quota=post04*jinshi2quota

* the raito of officials to jinshi
gen official2jinshi=official/jinshi
gen post04_official2jinshi=post04*official2jinshi


******************* Weather shocks

gen weathershock1=1 if mdf_ds>=1|mdf_ds<=-1
replace weathershock=0 if weathershock==.

* the interaction of weather shock with lnquota and  lnpop

foreach x of var weathershock1 {
sum `x'
gen `x'quota=(`x'-r(mean))*(lnquota-4.440656) 
sum `x'
gen `x'pop=(`x'-r(mean))*(lnpop-13.61967) 
}

* interaction with post-abolition dummy
foreach x of var weathershock1  sd_mdf_ds{
gen post04_`x'=post04*`x'
sum `x'
gen post04_lnquota_`x'=post04*(lnquota-4.440656)*(`x'-r(mean))
gen post04_lnpop_`x'=post04*(lnpop-13.61967)*(`x'-r(mean))
}


****************** Modern human capital

* dummy indicator of modern human capital
gen ndfirm_d=(ndfirm>0)
gen japan_d=(japan>0)

* log-term of firms
gen lnndfirm=ln(ndfirm+1)
sum lnndfirm
gen lnfirm_post04=(lnndfirm-r(mean))*post04

* log-term of japanese students
gen lnjapan=ln(japan+1)
sum lnjapan
gen lnjapan_post04=(lnjapan-r(mean))*post04




****************** Party Identity

gen KMT_d=(KMT>0)
gen NonKMT_d=(NonKMT>0)

gen difKMT_d=KMT_d-NonKMT_d
gen difKMT=KMT-NonKMT



****************** Newspaper
foreach x of varlist newspc {
gen post04_`x'=post04*`x'
gen post04_`x'_lnq=post04*`x'*(lnquota-4.440656)
gen post04_`x'_lnpop=post04*`x'*(lnpop-13.61967)
}


****************** Enclaves dummy

foreach x of varlist concession jpnconcession {
gen post04_`x'=post04*`x'
gen post04_`x'_lnq=post04*`x'*(lnquota-4.440656)
gen post04_`x'_lnpop=post04*`x'*(lnpop-13.61967)
}







************************************************************************************************************************************
**********************************         Regressions

************************************************************************************************************************************




************ Table 1: summary
sum member_d member 
sum rebeldum if year==1906
sum quota lnquota jinshi official lnpop lnsize treaty small middle large mainriver coast rivernum2riv lnriverl change_p1p0 boxer ranka_p normal_ranka foxmillet rice spotato mean_mdf_ds hh_subbasin  if year==1906
sum  ndfirm japan
sum fragm rqindex taxpc1820 pcapital rankb_p rankc_p rankd_p newspc concession if year==1906




********************************** Table 2 (columns 1-5: Yearly): The Impact of Quotas I: On Revolution Participation
 
xi: xtreg member_d lnquota_post04  i.year, fe cluster(prefid)
outreg2 lnquota_post04 post04_lnpop using Tables\Table_2_Yearly.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg member_d lnquota_post04 i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04 post04_lnpop using Tables\Table_2_Yearly.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_lnpop post04_lnsize post04_coast post04_mainriver  ///
post04_treaty post04_small post04_middle post04_large   i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_lnpop post04_lnsize  post04_coast post04_mainriver  post04_treaty   post04_small post04_middle post04_large   using Tables\Table_2_Yearly.doc, se  bdec(3) rdec(3) nocons append

**************** Polynomials
xi: xtreg member_d  lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize post04_coast post04_mainriver  ///
post04_treaty post04_small post04_middle post04_large   i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty   post04_small post04_middle post04_large   using Tables\Table_2_Yearly.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  ///
post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  [aw=1/pop], fe cluster(prefid)
outreg2 lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty   post04_small post04_middle post04_large  using Tables\Table_2_Yearly.doc, se  bdec(3) rdec(3) nocons append





********************************** Table 3: The Impact of Quotas II: On Early Uprisings in 1911 and the Boxer Rebellion

***********  columns 1-5, the effect on boxer uprising vs. Xinhai Revolution 

xi: reg rebeldum lnquota  lnpop  i.provcd if year==1906 , cluster(prefid)
outreg2 lnquota  lnpop  using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons replace

xi: reg rebeldum lnquota  lnpop   lnsize coast   mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 lnquota  lnpop   lnsize coast   mainriver treaty small middle large  using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append

xi: reg rebeldum lnquota  lnpop  lnpop2 lnpop3  lnsize coast   mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 lnquota  lnpop  lnpop2 lnpop3 lnsize coast   mainriver treaty small middle large  using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append

********** Controlling for newspapers per thousand populatioin
xi: reg rebeldum lnquota lnpop  lnpop2 lnpop3 newspc   lnsize coast   mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 lnquota   lnpop  lnpop2 lnpop3 newspc lnsize coast   mainriver treaty small middle large  using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append

************** If latitude>26.9
xi: reg rebeldum lnquota  lnpop  lnpop2 lnpop3 newspc lnsize coast   mainriver treaty small middle large  i.provcd if year==1906&north==1, cluster(prefid)
outreg2 lnquota   lnpop  lnpop2 lnpop3 newspc lnsize coast   mainriver treaty small middle large  using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append


***********  columns 6-9, the effect on boxer uprising 

xi: reg boxer lnquota  lnpop  i.provcd if year==1906 , cluster(prefid)
outreg2 lnquota   lnpop  using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append

xi: reg boxer lnquota  lnpop   lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 lnquota lnpop    lnsize coast  mainriver treaty small middle large using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append

xi: reg boxer lnquota  lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append

************** If latitude>26.9
xi: reg boxer lnquota  lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906&north==1, cluster(prefid)
outreg2 lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large using Tables\Table_3.doc, se  bdec(3) rdec(3) nocons append






**************** Figure 4: Small Rivers, Counties and Quotas
twoway (scatter cnty2riverl rivernum2riv  if year==1906) (lfit cnty2riverl rivernum2riv  if year==1906, lp(solid) ), scheme (s2mono)  graphregion(color(white)) ytitle (# counties/River Length) 
graph export Figures\Figure_4a.png, replace

twoway (scatter lnquota2riverl cnty2riverl if year==1906) (lfit lnquota2riverl cnty2riverl   if year==1906, lp(solid) ), scheme (s2mono)  graphregion(color(white)) ytitle (ln(Quotas/River Length)) 
graph export Figures\Figure_4b.png, replace


********************************** Table 4: Relevance and Placebo Tests of the Two Instruments


**************** Table 4(a) IV1: #small river / river length


** a.1 The effect on  Quota
xi: reg lnquota  rivernum2riv  mainriver  lnriverl lnsize lnpop lnpop2 lnpop3 coast treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons replace

xi: reg lnquota0  rivernum2riv  mainriver   lnriverl lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large i.provcd if year==1906 , cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append


xi: reg delquota rivernum2riv mainriver    lnriverl lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large i.provcd if year==1906 , cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append

** a.2: The effect on transportation -- Communication center (Chong)

xi: reg  ranka_p rivernum2riv mainriver    lnriverl  lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append

xi: reg normal_ranka rivernum2riv mainriver    lnriverl  lnsize lnpop  lnpop2 lnpop3  coast treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append


** a.3: The effect on Crop suitability

xi: reg rice rivernum2riv mainriver     lnriverl  lnsize lnpop  lnpop2 lnpop3 coast  treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append

xi: reg foxmillet rivernum2riv mainriver     lnriverl  lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append

xi: reg  spotato rivernum2riv mainriver     lnriverl  lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append

xi: reg  mean_mdf_ds rivernum2riv mainriver     lnriverl  lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append

***
xi: reg  hh_subbasin rivernum2riv mainriver     lnriverl  lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 rivernum2riv    lnriverl mainriver using Tables\Table_4a.doc, se  bdec(3) rdec(3) nocons append




**************** Table 4(b) IV2: short-run change in performance

** b.1 The effect on  Quota

xi: reg  lnquota change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0 using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons replace

xi: reg  lnquota0 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

xi: reg  delquota change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0    using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

** b.2 The effect on  Quota

xi: reg  change_p2p1 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

xi: reg  change_p3p2 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large   i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

xi: reg  change_p4p3 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large   i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

xi: reg  change_p5p4 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

xi: reg  change_p6p5 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large   i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append

xi: reg  change_p7p6 change_p1p0 lnpscholar0 mainriver lnsize lnpop  lnpop2 lnpop3  coast  treaty small middle large  i.provcd if year==1906 , cluster(prefid)
outreg2 change_p1p0  using Tables\Table_4b.doc, se  bdec(3) rdec(3) nocons append



********************************** Table 5: The Impact of Quotas III: Results from Instrumental Variables
**iv 1

# delimit ;
xi: xtreg  member_d  post04_rivernum2riv  
post04_mainriver post04_lnriverl
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe;
outreg2 post04_rivernum2riv  using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons replace;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_rivernum2riv)
post04_mainriver post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04  using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_rivernum2riv)
post04_mainriver post04_lnriverl post04_change_p1p0  post04_lnpscholar0  
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_change_p1p0 using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


********  iv2
# delimit ;
xi: xtreg  member_d   post04_change_p1p0  post04_lnpscholar0
post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe;
outreg2  post04_change_p1p0   using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_change_p1p0) 
post04_lnpscholar0
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04    using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr

# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_change_p1p0) 
post04_lnpscholar0 post04_rivernum2riv  post04_mainriver post04_lnriverl
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04    post04_rivernum2riv   using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


*************both IVs
************************************************************
# delimit ;
xi: xtreg  member_d post04_rivernum2riv  post04_mainriver  post04_lnriverl post04_change_p1p0  post04_lnpscholar0
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe ;
outreg2  post04_rivernum2riv   post04_change_p1p0  using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_rivernum2riv post04_change_p1p0)
post04_mainriver  post04_lnriverl   post04_lnpscholar0 
post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
xtoverid;
outreg2 lnquota_post04   using Tables\Table_5.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr






********************************** Table 6B: The Role of Prospect II: the Impact of Heterogeneous Returns from the Exam


xi: xtreg member_d  lnquota_post04  lnoff_post04  ///
post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver   post04_treaty post04_small post04_middle post04_large i.provcd*i.year, fe cluster(prefid) 
outreg2  lnquota_post04  lnoff_post04 using Tables\Table_6b.doc, se  bdec(3) rdec(3) nocons replace

   
xi: xtreg member_d  lnquota_post04  lnoff_post04  lnoffquota_post04  ///
post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver   post04_treaty post04_small post04_middle post04_large i.provcd*i.year, fe cluster(prefid)
outreg2  lnquota_post04  lnoff_post04  lnoffquota_post04 using Tables\Table_6b.doc, se  bdec(3) rdec(3) nocons append

   
xi: xtreg member_d  lnquota_post04  lnoff_post04  lnoffquota_post04  lnoffpop_post04 ///
post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver   post04_treaty post04_small post04_middle post04_large i.provcd*i.year, fe cluster(prefid)
outreg2  lnquota_post04  lnoff_post04  lnoffquota_post04  lnoffpop_post04 using Tables\Table_6b.doc, se  bdec(3) rdec(3) nocons append

   
xi: xtreg member_d  lnquota_post04  lnoff_post04  lnoffquota_post04  lnoffpop_post04 ///
lnoff1905_post04  lnoff1905quota_post04 ///
post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver   post04_treaty post04_small post04_middle post04_large i.provcd*i.year, fe cluster(prefid)
outreg2  lnquota_post04  lnoff_post04  lnoffquota_post04  lnoffpop_post04 lnoff1905_post04  lnoff1905quota_post04 using Tables\Table_6b.doc, se  bdec(3) rdec(3) nocons append

  
xi: xtreg member_d  lnquota_post04  lnoff_post04  lnoffquota_post04  lnoffpop_post04 ///
lnoff1905_post04  lnoff1905quota_post04 lnoff1905pop_post04 ///
post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver   post04_treaty post04_small post04_middle post04_large i.provcd*i.year, fe cluster(prefid)
outreg2  lnquota_post04  lnoff_post04  lnoffquota_post04  lnoffpop_post04 lnoff1905_post04  lnoff1905quota_post04 lnoff1905pop_post04 using Tables\Table_6b.doc, se  bdec(3) rdec(3) nocons append
  

  
  
  
  
********************************** Table 7: Examining the Impact of Social Capital
  
xi: xtreg member_d  lnquota_post04  post04_fragm post04_lnpop  post04_lnpop2 post04_lnpop3 i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_fragm using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg member_d  lnquota_post04  post04_fragm post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_fragm using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append


xi: xtreg member_d  lnquota_post04  post04_fragm post04_fragm_lnq    post04_fragm_lnpop  post04_lnpop post04_lnpop2 post04_lnpop3 i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_fragm post04_fragm_lnq   post04_fragm_lnpop   using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_fragm post04_fragm_lnq   post04_fragm_lnpop  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_fragm post04_fragm_lnq   post04_fragm_lnpop  using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append

***
xi: xtreg member_d  lnquota_post04  post04_rqindex post04_lnpop post04_lnpop2 post04_lnpop3 i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_rqindex using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_rqindex post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_rqindex using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_rqindex post04_rqindex_lnq post04_rqindex_lnpop  post04_lnpop post04_lnpop2 post04_lnpop3 i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_rqindex post04_rqindex_lnq post04_rqindex_lnpop  using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_rqindex post04_rqindex_lnq post04_rqindex_lnpop  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2  lnquota_post04 post04_rqindex post04_rqindex_lnq post04_rqindex_lnpop  using Tables\Table_7.doc, se  bdec(3) rdec(3) nocons append

 
 
 
********************************** Table 8A: The Role of Existing Elites I: Importance of Prospect 

xi: xtreg member_d post04_quota2popu   post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver   post04_treaty post04_small post04_middle post04_large i.provcd*i.year, fe cluster(prefid)
outreg2  post04_quota2popu using Tables\Table_8a.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg member_d post04_jinshi2quota post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize post04_coast  post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.provcd*i.year, fe cluster(prefid)
outreg2  post04_jinshi2quota  using Tables\Table_8a.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d post04_official2jinshi  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_mainriver post04_treaty post04_small post04_middle post04_large  i.provcd*i.year, fe cluster(prefid)
outreg2 post04_official2jinshi  using Tables\Table_8a.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d post04_quota2popu  post04_jinshi2quota post04_official2jinshi   post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_treaty post04_small post04_middle post04_large post04_coast   post04_mainriver i.provcd*i.year, fe cluster(prefid)
outreg2  post04_quota2popu  post04_jinshi2quota post04_official2jinshi  using Tables\Table_8a.doc, se  bdec(3) rdec(3) nocons append


  
  
  
********************************** Table 8B: The Role of Existing Elites II: Importance of Public Goods

xi: xtreg member_d lnquota_post04  post04_sd_mdf_ds post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04 post04_sd_mdf_ds using Tables\Table_8b.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg member_d lnquota_post04  post04_sd_mdf_ds post04_lnquota_sd_mdf_ds  post04_lnpop_sd_mdf_ds  post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04 post04_sd_mdf_ds post04_lnquota_sd_mdf_ds post04_lnpop_sd_mdf_ds using Tables\Table_8b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  weathershock1 post04_weathershock1 post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  weathershock1 post04_weathershock1 using Tables\Table_8b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  weathershock1 post04_weathershock1  weathershock1quota weathershock1pop post04_lnquota_weathershock1 post04_lnpop_weathershock1 post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  weathershock1 post04_weathershock1 weathershock1quota weathershock1pop post04_lnquota_weathershock1 post04_lnpop_weathershock1 using Tables\Table_8b.doc, se  bdec(3) rdec(3) nocons append



********************************** Table 9: Evaluating the Impact of Modern Human Capital

********* effect on modern human capital
xi: xtreg ndfirm_d  lnquota_post04  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2   lnquota_post04  using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg lnndfirm  lnquota_post04  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2   lnquota_post04   using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg japan_d lnquota_post04  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2   lnquota_post04   using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg lnjapan lnquota_post04  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2  lnquota_post04   using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append


********** effect on revolutionary

xi: xtreg member_d  lnndfirm lnfirm_post04 post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2   lnndfirm lnfirm_post04  using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04 lnndfirm lnfirm_post04 post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2  lnquota_post04  lnndfirm lnfirm_post04   using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnjapan lnjapan_post04 post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2  lnjapan lnjapan_post04  using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  lnjapan lnjapan_post04 post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  lnjapan lnjapan_post04  using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04 lnndfirm lnfirm_post04 lnjapan lnjapan_post04 post04_lnpop post04_lnpop2 post04_lnpop3  post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04 lnndfirm lnfirm_post04 lnjapan lnjapan_post04  using Tables\Table_9.doc, se  bdec(3) rdec(3) nocons append




********************************** Table 10B: Checking the Role of State Capacity II: Results Using Importance Measures

xi: xtreg member_d lnquota_post04  post04_taxpc1820 post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_taxpc1820  using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg member_d lnquota_post04  post04_pcapital post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04   post04_pcapital  using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  post04_ranka_p  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_ranka_p   using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  post04_rankb_p  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_rankb_p  using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  post04_rankc_p post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_rankc_p  using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  post04_rankd_p post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  post04_rankd_p  using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d lnquota_post04  post04_pcapital  post04_taxpc1820   post04_lnpop2 post04_lnpop3 post04_ranka_p  post04_rankb_p  post04_rankc_p post04_rankd_p post04_lnpop post04_lnsize  post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe cluster(prefid)
outreg2 lnquota_post04  lnquota_post04  post04_pcapital  post04_taxpc1820  post04_ranka_p  post04_rankb_p  post04_rankc_p post04_rankd_p   using Tables\Table_10b.doc, se  bdec(3) rdec(3) nocons append







************************************************************************************************************************************
*****************************************                         Online Appendix 

************************************************************************************************************************************


********************************** Table A.1: Quotas per capita and Prefecture Characteristics

xi: reg lnquota  lnpop   if year==1906 , cluster(prefid)
outreg2 lnpop using Tables\Table_A1.doc, se  bdec(3) rdec(3) nocons replace

xi: reg lnquota  lnpop  i.provcd if year==1906 , cluster(prefid)
outreg2 lnpop using Tables\Table_A1.doc, se  bdec(3) rdec(3) nocons append

xi: reg lnquota  lnpop  lnpop2 lnpop3  lnsize coast i.provcd if year==1906 , cluster(prefid)
outreg2 lnpop lnpop2 lnpop3 lnsize coast using Tables\Table_A1.doc, se  bdec(3) rdec(3) nocons append

xi: reg lnquota  lnpop  lnpop2 lnpop3  lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2 lnpop lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large using Tables\Table_A1.doc, se  bdec(3) rdec(3) nocons append

xi: reg lnquota  lnpop  lnpop2 lnpop3  lnsize coast  mainriver treaty small middle large pcapital  taxpc1820  ranka_p  rankb_p  rankc_p rankd_p i.provcd if year==1906, cluster(prefid)
outreg2 lnpop lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large pcapital  taxpc1820  ranka_p  rankb_p  rankc_p rankd_p using Tables\Table_A1.doc, se  bdec(3) rdec(3) nocons append



********************************** Table A.2: Using the Number of Revolutionaries as an Alternative Outcome

xi: xtreg member  lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver ///
post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year [aw=1/pop], fe cluster(prefid)
outreg2 lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty   post04_small post04_middle post04_large  using Tables\Table_A2.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg membersh  lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver ///
post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  [aw=1/pop], fe  cluster(prefid)
outreg2 lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty   post04_small post04_middle post04_large  using Tables\Table_A2.doc, se  bdec(3) rdec(3) nocons append

xi: xtpoisson member  lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver ///
post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year, fe
outreg2 lnquota_post04  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast post04_mainriver  post04_treaty   post04_small post04_middle post04_large  using Tables\Table_A2.doc, se  bdec(3) rdec(3) nocons append






********************************** Table A.3: The Dynamic Effects of Quotas on the Revolutionary Indicator


local control_yfe "lnpop_year* lnpop2_year* lnpop3_year*"
xi: xtreg member_d lnquota_year2-lnquota_year7 `control_yfe' i.year*i.provcd i.year, fe  cluster(prefid)
outreg2 lnquota_year2-lnquota_year7   using Tables\Table_A3.doc, se  bdec(3) rdec(3) nocons replace
lincom (lnquota_year6+lnquota_year7)*0.5-(lnquota_year4+lnquota_year5)*0.5

local control_yfe "lnpop_year* lnpop2_year* lnpop3_year* coast_year*  mainriver_year* lnsize_year*  "
xi: xtreg member_d lnquota_year2-lnquota_year7 `control_yfe' i.year*i.provcd i.year, fe  cluster(prefid)
outreg2 lnquota_year2-lnquota_year7   using Tables\Table_A3.doc, se  bdec(3) rdec(3) nocons append
lincom (lnquota_year6+lnquota_year7)*0.5-(lnquota_year4+lnquota_year5)*0.5

local control_yfe "lnpop_year* lnpop2_year* lnpop3_year* coast_year*  mainriver_year* lnsize_year* treaty_year* small_year* middle_year* large_year*"
xi: xtreg member_d lnquota_year2-lnquota_year7 `control_yfe' i.year*i.provcd i.year, fe  cluster(prefid)
outreg2 lnquota_year2-lnquota_year7   using Tables\Table_A3.doc, se  bdec(3) rdec(3) nocons append
lincom (lnquota_year6+lnquota_year7)*0.5-(lnquota_year4+lnquota_year5)*0.5

local control_yfe "lnpop_year* lnpop2_year* lnpop3_year* coast_year*  mainriver_year* lnsize_year* treaty_year* small_year* middle_year* large_year*"
xi: xtreg member_d lnquota_year2-lnquota_year7 `control_yfe' i.year*i.provcd i.year [aw=1/pop], fe  cluster(prefid)
outreg2 lnquota_year2-lnquota_year7   using Tables\Table_A3.doc, se  bdec(3) rdec(3) nocons append
lincom (lnquota_year6+lnquota_year7)*0.5-(lnquota_year4+lnquota_year5)*0.5
outreg2 lnquota_year2-lnquota_year7   using Figures\Source_Figure_3b.doc, se  bdec(3) rdec(3) nocons replace




********************************** Table A.5: Quotas and Party Identification


xi: reg KMT_d  lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2  lnquota using Tables\Table_A5_Pref.doc, se  bdec(3) rdec(3) nocons replace

xi: reg NonKMT_d  lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2  lnquota using Tables\Table_A5_Pref.doc, se  bdec(3) rdec(3) nocons append

xi: reg difKMT_d  lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2  lnquota using Tables\Table_A5_Pref.doc, se  bdec(3) rdec(3) nocons append

xi: reg KMT  lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2  lnquota using Tables\Table_A5_Pref.doc, se  bdec(3) rdec(3) nocons append

xi: reg NonKMT  lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2  lnquota using Tables\Table_A5_Pref.doc, se  bdec(3) rdec(3) nocons append

xi: reg  difKMT  lnquota lnpop  lnpop2 lnpop3 lnsize coast  mainriver treaty small middle large  i.provcd if year==1906, cluster(prefid)
outreg2  lnquota using Tables\Table_A5_Pref.doc, se  bdec(3) rdec(3) nocons append




********************************** Table A.6: Examining the Impact of International Inuence

xi: xtreg member_d  lnquota_post04  post04_newspc post04_newspc_lnq  post04_newspc_lnpop  post04_lnpop post04_lnpop2 post04_lnpop3 post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2 lnquota_post04   post04_newspc post04_newspc_lnq  post04_newspc_lnpop using Tables\Table_A6.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg member_d  lnquota_post04  post04_concession post04_concession_lnq  post04_concession_lnpop  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2 lnquota_post04  post04_concession post04_concession_lnq post04_concession_lnpop using Tables\Table_A6.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04   post04_jpnconcession post04_jpnconcession_lnq  post04_jpnconcession_lnpop  post04_lnpop  post04_lnpop2 post04_lnpop3  post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2 lnquota_post04    post04_jpnconcession post04_jpnconcession_lnq  post04_jpnconcession_lnpop   using Tables\Table_A6.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_concession post04_concession_lnq post04_concession_lnpop   post04_jpnconcession post04_jpnconcession_lnq  post04_jpnconcession_lnpop  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2 lnquota_post04  post04_concession post04_concession_lnq post04_concession_lnpop   post04_jpnconcession post04_jpnconcession_lnq  post04_jpnconcession_lnpop   using Tables\Table_A6.doc, se  bdec(3) rdec(3) nocons append

xi: xtreg member_d  lnquota_post04  post04_concession post04_concession_lnq post04_concession_lnpop   post04_newspc post04_newspc_lnq  post04_newspc_lnpop post04_jpnconcession post04_jpnconcession_lnq  post04_jpnconcession_lnpop  post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize post04_mainriver post04_coast post04_treaty post04_small post04_middle post04_large  i.year*i.provcd i.year  , fe cluster(prefid)
outreg2 lnquota_post04  post04_concession post04_concession_lnq post04_concession_lnpop   post04_newspc post04_newspc_lnq  post04_newspc_lnpop post04_jpnconcession post04_jpnconcession_lnq  post04_jpnconcession_lnpop   using Tables\Table_A6.doc, se  bdec(3) rdec(3) nocons append




********************************** Table A.7: Robustness Checks of Using Small Rivers

# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_river70num2riv post04_change_p1p0)
 post04_lnpscholar0  
post04_othriver70num2riv
post04_mainriver  post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_othriver70num2riv  post04_lnriverl using Tables\Table_A7.doc, se  bdec(3) rdec(3) nocons replace;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_river80num2riv post04_change_p1p0)
 post04_lnpscholar0  
post04_othriver80num2riv
post04_mainriver  post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_othriver80num2riv  post04_lnriverl using Tables\Table_A7.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr



# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_river90num2riv post04_change_p1p0)
 post04_lnpscholar0  
post04_othriver90num2riv
post04_mainriver  post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_othriver90num2riv  post04_lnriverl using Tables\Table_A7.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr



# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_river100num2riv post04_change_p1p0)
 post04_lnpscholar0  
post04_othriver100num2riv
post04_mainriver  post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_othriver100num2riv  post04_lnriverl using Tables\Table_A7.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_river110num2riv post04_change_p1p0)
 post04_lnpscholar0 
post04_othriver110num2riv
post04_mainriver  post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_othriver110num2riv  post04_lnriverl using Tables\Table_A7.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr


# delimit ;
xi: xtivreg2  member_d  (lnquota_post04 = post04_river120num2riv post04_change_p1p0)
 post04_lnpscholar0 
post04_othriver120num2riv
post04_mainriver  post04_lnriverl   
post04_lnpop  post04_lnpop2 post04_lnpop3 post04_lnsize  post04_coast  post04_treaty post04_small post04_middle post04_large 
post04_ranka_p  post04_rice post04_foxmillet post04_spotato  post04_mean_mdf_ds 
i.provcd*i.year i.year 
, fe first;
outreg2 lnquota_post04 post04_othriver120num2riv  post04_lnriverl using Tables\Table_A7.doc, se  bdec(3) rdec(3) nocons append;
# delimit cr



















