**********Software version: Stata/MP 13.1


clear all
clear
capture log close
set more off


* Change Directory to "\DataFiles"
cd "C:\Dropbox\CivilExam\FinalFiles\DataFiles"
use Data\ProvYear.dta, clear




************************************************************************************************************************************
**********************************        Variables definition

************************************************************************************************************************************


sort provcd year
tsset provcd year


******************* Land Tax
gen lnlandtax=ln(landtax)

******************* Non-agricultural Tax
gen lncommercial=ln(commercial)

* Polynomials of ln popu.
sum lnpop
gen lnpop2=(lnpop-16.62056)^2
gen lnpop3=(lnpop-16.62056)^3


* Gen post-abolition dummy
gen post04=(year>=1905)

******************** Interaction with post-abolition dummy
foreach x of varlist lnquota lnpop lnsize coast mainriver treaty small middle large lnpop2 lnpop3  {
gen post04_`x'=post04*`x'
}




******************** Interaction with year dummies

tabu year, gen (ydummy)
sum ydummy*


* Year dummies
forvalues i=1(1)20 { 
gen lnquota_year`i'=ydummy`i'*lnquota
}


forvalues i=1(1)20 { 
gen lnpop_year`i'=ydummy`i'*lnpop
gen lnsize_year`i'=ydummy`i'*lnsize
gen coast_year`i'=ydummy`i'*coast
gen mainriver_year`i'=ydummy`i'*mainriver
gen treaty_year`i'=ydummy`i'*treaty
gen small_year`i'=ydummy`i'*small
gen middle_year`i'=ydummy`i'*middle
gen large_year`i'=ydummy`i'*large
gen lnpop2_year`i'=ydummy`i'*lnpop2
gen lnpop3_year`i'=ydummy`i'*lnpop3
}







************************************************************************************************************************************
**********************************         Regressions

************************************************************************************************************************************


********************** Table 10A: Checking Changes in State Capacity I: Examining Taxes

xi: xtreg lnlandtax post04_lnquota post04_lnpop    i.year, fe cluster(provcd)
outreg2 post04_lnquota using Tables\Table_10a.doc, se  bdec(3) rdec(3) nocons replace

xi: xtreg lnlandtax post04_lnquota post04_lnpop post04_lnsize post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large i.year, fe cluster(provcd)
outreg2 post04_lnquota using Tables\Table_10a.doc, se  bdec(3) rdec(3) nocons append


xi: xtreg lnlandtax post04_lnquota post04_lnpop  post04_lnpop2  post04_lnpop3 post04_lnsize post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large i.year, fe cluster(provcd)
outreg2 post04_lnquota using Tables\Table_10a.doc, se  bdec(3) rdec(3) nocons append


xi: xtreg lncommercial post04_lnquota post04_lnpop  i.year, fe cluster(provcd)
outreg2 post04_lnquota using Tables\Table_10a.doc, se  bdec(3) rdec(3) nocons append


xi: xtreg lncommercial post04_lnquota post04_lnpop post04_lnsize post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large i.year, fe cluster(provcd)
outreg2 post04_lnquota using Tables\Table_10a.doc, se  bdec(3) rdec(3) nocons append


xi: xtreg lncommercial post04_lnquota post04_lnpop post04_lnpop2  post04_lnpop3 post04_lnsize post04_coast post04_mainriver post04_treaty post04_small post04_middle post04_large  i.year, fe cluster(provcd)
outreg2  post04_lnquota using Tables\Table_10a.doc, se  bdec(3) rdec(3) nocons append






********************** Table A.8: Examining Taxes Year by Year

****************************************************************************************************
local control_yfe "lnpop_year*"
xi: xtreg lnlandtax  lnquota_year13 lnquota_year18 `control_yfe'  i.year, fe  cluster(provcd)
outreg2  lnquota_year13 lnquota_year18 using Tables\Table_A8.doc, se  bdec(3) rdec(3) nocons replace


local control_yfe "lnpop_year* lnsize_year*  coast_year* mainriver_year* treaty_year* small_year* middle_year* large_year*  "
xi: xtreg lnlandtax  lnquota_year13 lnquota_year18 `control_yfe'  i.year, fe  cluster(provcd)
outreg2 lnquota_year13 lnquota_year18 using Tables\Table_A8.doc, se  bdec(3) rdec(3) nocons append

local control_yfe "lnpop_year*"
xi: xtreg lncommercial  lnquota_year2-lnquota_year20 `control_yfe'  i.year, fe  cluster(provcd)
outreg2  lnquota_year2-lnquota_year20 using Tables\Table_A8.doc, se  bdec(3) rdec(3) nocons append


local control_yfe "lnpop_year* lnsize_year*  coast_year* mainriver_year* treaty_year* small_year* middle_year* large_year*  "
xi: xtreg lncommercial  lnquota_year2-lnquota_year20 `control_yfe'  i.year, fe  cluster(provcd)
outreg2 lnquota_year2-lnquota_year20 using Tables\Table_A8.doc, se  bdec(3) rdec(3) nocons append
















